@@ -122,6 +122,7 @@ DEFAULT_VALID_LICENSES = (
     'Creative Commons Attribution-ShareAlike',
     # Others:
     'Design Public License',  # ???
+    'FSFAP',  # FSF All Permissive license
     'GFDL',  # GNU Free Documentation License
     'LaTeX Project Public License',
     'OpenContent License',
@@ -397,6 +398,9 @@ BAD_WORDS = {
     'xwindows': 'X'
 }
 
+CAPITALIZED_IGNORE_LIST = (
+    'jQuery', 'openSUSE', 'wxWidgets', 'a', 'an', 'uWSGI')
+
 DEFAULT_INVALID_REQUIRES = ('^is$', '^not$', '^owned$', '^by$', '^any$',
                             '^package$', r'^libsafe\.so\.')
 
@@ -704,6 +708,9 @@ class TagsCheck(AbstractCheck.AbstractCheck):
             else:
                 for lang in langs:
                     self.check_description(pkg, lang, ignored_words)
+
+            if len(Pkg.b2s(description)) < len(pkg[rpm.RPMTAG_SUMMARY]):
+                printWarning(pkg, 'description-shorter-than-summary')
         else:
             printError(pkg, 'no-description-tag')
 
@@ -823,20 +830,26 @@ class TagsCheck(AbstractCheck.AbstractCheck):
 
         # TODO: should take versions, <, <=, =, >=, > into account here
         #       https://bugzilla.redhat.com/460872
-        useless_provides = []
+        useless_provides = set()
         for p in prov_names:
-            if prov_names.count(p) != 1 and p not in useless_provides:
-                useless_provides.append(p)
-        for p in useless_provides:
+            if (prov_names.count(p) != 1 and
+                    not p.startswith('debuginfo(') and
+                    p not in useless_provides):
+                useless_provides.add(p)
+        for p in sorted(useless_provides):
             printError(pkg, 'useless-provides', p)
 
-        for p in pkg.provides():
-            value = Pkg.formatRequire(*p)
-            self._unexpanded_macros(pkg, 'Provides %s' % (value,), value)
-
-        for c in pkg.conflicts():
-            value = Pkg.formatRequire(*c)
-            self._unexpanded_macros(pkg, 'Conflicts %s' % (value,), value)
+        for tagname, items in (
+                ('Provides', pkg.provides()),
+                ('Conflicts', pkg.conflicts()),
+                ('Obsoletes', pkg.obsoletes()),
+                ('Supplements', pkg.supplements()),
+                ('Suggests', pkg.suggests()),
+                ('Enhances', pkg.enhances()),
+                ('Recommends', pkg.recommends())):
+            for p in items:
+                value = Pkg.formatRequire(*p)
+                self._unexpanded_macros(pkg, '%s %s' % (tagname, value), value)
 
         obss = pkg.obsoletes()
         if obss:
@@ -907,7 +920,8 @@ class TagsCheck(AbstractCheck.AbstractCheck):
         spell_check(pkg, summary, 'Summary(%s)', lang, ignored_words)
         if '\n' in summary:
             printError(pkg, 'summary-on-multiple-lines', lang)
-        if summary[0] != summary[0].upper():
+        if (summary[0] != summary[0].upper() and
+                summary.partition(' ')[0] not in CAPITALIZED_IGNORE_LIST):
             printWarning(pkg, 'summary-not-capitalized', lang, summary)
         if summary[-1] == '.':
             printWarning(pkg, 'summary-ended-with-dot', lang, summary)
@@ -988,6 +1002,10 @@ Name tag.''',
 '''The major number of the library isn't included in the package's name.
 ''',
 
+'description-shorter-than-summary',
+'''The package description should be longer than the summary. Be a bit more
+verbose, please.''',
+
 'no-provides',
 '''Your library package doesn't provide the -devel name without the major
 version included.''',
@@ -1106,7 +1124,7 @@ once.''',
 '''This rpm requires a specific release of another package.''',
 
 'no-url-tag',
-'''The URL tag is missing.''',
+'''The URL tag is missing. Please add a http or ftp link to the project location.''',
 
 'name-repeated-in-summary',
 '''The name of the package is repeated in its summary.  This is often redundant
